@@ -12,6 +12,7 @@ import (
 	"github.com/helmfile/helmfile/pkg/app"
 	"github.com/helmfile/helmfile/pkg/app/version"
 	"github.com/helmfile/helmfile/pkg/config"
+	"github.com/helmfile/helmfile/pkg/envvar"
 	"github.com/helmfile/helmfile/pkg/errors"
 	"github.com/helmfile/helmfile/pkg/helmexec"
 )
@@ -40,7 +41,7 @@ func toCLIError(g *config.GlobalImpl, err error) error {
 }
 
 // NewRootCmd creates the root command for the CLI.
-func NewRootCmd(globalConfig *config.GlobalOptions, args []string) (*cobra.Command, error) {
+func NewRootCmd(globalConfig *config.GlobalOptions) (*cobra.Command, error) {
 	cmd := &cobra.Command{
 		Use:           "helmfile",
 		Short:         globalUsage,
@@ -75,11 +76,12 @@ func NewRootCmd(globalConfig *config.GlobalOptions, args []string) (*cobra.Comma
 
 	// when set environment HELMFILE_UPGRADE_NOTICE_DISABLED any value, skip upgrade notice.
 	var versionOpts []extension.CobraOption
-	if os.Getenv("HELMFILE_UPGRADE_NOTICE_DISABLED") == "" {
+	if os.Getenv(envvar.UpgradeNoticeDisabled) == "" {
 		versionOpts = append(versionOpts, extension.WithUpgradeNotice("helmfile", "helmfile"))
 	}
 
 	cmd.AddCommand(
+		NewInitCmd(globalImpl),
 		NewApplyCmd(globalImpl),
 		NewBuildCmd(globalImpl),
 		NewCacheCmd(globalImpl),
