@@ -165,7 +165,7 @@ func TestApply_hooks(t *testing.T) {
 				t.Errorf("unexpected log:\nDIFF\n%s\nEOD", diff)
 			}
 		} else {
-			assertEqualsToSnapshot(t, "log", bs.String())
+			assertLogEqualsToSnapshot(t, bs.String())
 		}
 	}
 
