@@ -179,6 +179,7 @@ type LintConfigProvider interface {
 type FetchConfigProvider interface {
 	SkipDeps() bool
 	OutputDir() string
+	OutputDirTemplate() string
 
 	concurrencyConfig
 }
@@ -247,6 +248,10 @@ type ListConfigProvider interface {
 
 type CacheConfigProvider interface{}
 
+type InitConfigProvider interface {
+	Force() bool
+}
+
 // when enable reuse-values, reuse the last release's values and merge in any overrides values.
 type valuesControlMode interface {
 	ReuseValues() bool
