@@ -2,16 +2,12 @@ package config
 
 // DeleteOptions is the options for the build command
 type DeleteOptions struct {
-	// Args is the args to pass to helm exec
-	Args string
 	// Concurrency is the maximum number of concurrent helm processes to run, 0 is unlimited
 	Concurrency int
 	// Purge is the purge flag
 	Purge bool
 	// SkipDeps is the skip deps flag
 	SkipDeps bool
-	// Interactive is true if the user should be prompted for input.
-	Interactive bool
 }
 
 // NewDeleteOptions creates a new Apply
@@ -38,11 +34,6 @@ func (c *DeleteImpl) Concurrency() int {
 	return c.DeleteOptions.Concurrency
 }
 
-// Args returns the args
-func (c *DeleteImpl) Args() string {
-	return c.DeleteOptions.Args
-}
-
 // Purge returns the purge
 func (c *DeleteImpl) Purge() bool {
 	return c.DeleteOptions.Purge
@@ -52,8 +43,3 @@ func (c *DeleteImpl) Purge() bool {
 func (c *DeleteImpl) SkipDeps() bool {
 	return c.DeleteOptions.SkipDeps
 }
-
-// Interactive returns the Interactive
-func (c *DeleteImpl) Interactive() bool {
-	return c.DeleteOptions.Interactive
-}
