@@ -109,14 +109,6 @@ func TestHelmState_applyDefaultsTo(t *testing.T) {
 			},
 			want: specWithNamespace,
 		},
-		{
-			name:   "Has a namespace from flags",
-			fields: fieldsWithoutNamespace,
-			args: args{
-				spec: specWithNamespace,
-			},
-			want: specWithNamespace,
-		},
 		{
 			name:   "Has a namespace from flags and from spec",
 			fields: fieldsWithNamespace,
@@ -125,6 +117,22 @@ func TestHelmState_applyDefaultsTo(t *testing.T) {
 			},
 			want: specWithNamespaceFromFields,
 		},
+		{
+			name:   "Spec and flag Has no a namespace",
+			fields: fieldsWithoutNamespace,
+			args: args{
+				spec: specWithoutNamespace,
+			},
+			want: specWithoutNamespace,
+		},
+		{
+			name:   "Spec has no a namespace but from flag",
+			fields: fieldsWithNamespace,
+			args: args{
+				spec: specWithoutNamespace,
+			},
+			want: specWithNamespaceFromFields,
+		},
 	}
 	for i := range tests {
 		tt := tests[i]
