@@ -7,6 +7,7 @@ import (
 	"os"
 	"os/exec"
 	"path/filepath"
+	"regexp"
 	"runtime"
 	"strings"
 	"testing"
@@ -17,6 +18,11 @@ import (
 	"gopkg.in/yaml.v3"
 )
 
+var (
+	// e.g. https_github_com_cloudposse_helmfiles_git.ref=0.xx.0
+	chartGitFullPathRegex = regexp.MustCompile(`chart=.*git\.ref=.*/charts/.*`)
+)
+
 type ociChart struct {
 	name    string
 	version string
@@ -172,6 +178,10 @@ func TestHelmfileTemplateWithBuildCommand(t *testing.T) {
 
 			gotStr := string(got)
 			gotStr = strings.ReplaceAll(gotStr, fmt.Sprintf("chart=%s", wd), "chart=$WD")
+
+			// Replace go-getter path with $GoGetterPath
+			gotStr = chartGitFullPathRegex.ReplaceAllString(gotStr, `chart=$$GoGetterPath`)
+
 			// OCI based helm charts are pulled and exported under temporary directory.
 			// We are not sure the exact name of the temporary directory generated by helmfile,
 			// so redact its base directory name with $TMP.
