@@ -2,12 +2,14 @@ package helmfile
 
 import (
 	"bytes"
+	"fmt"
 	"os"
 	"testing"
 	"text/template"
 
 	"github.com/stretchr/testify/require"
 
+	"github.com/helmfile/helmfile/pkg/filesystem"
 	"github.com/helmfile/helmfile/pkg/tmpl"
 )
 
@@ -264,12 +266,36 @@ func (t *tmplE2e) load() {
 
 var tmplE2eTest = tmplE2e{}
 
+func TestFileRendering(t *testing.T) {
+	tmplE2eTest.load()
+
+	for _, tc := range tmplE2eTest.tcs {
+		t.Run(tc.name, func(t *testing.T) {
+			tc.setEnvs(t)
+			tempDir, _ := os.MkdirTemp("./testdata", "test")
+			defer os.RemoveAll(tempDir)
+
+			filename := fmt.Sprintf("%s/%s.gotmpl", tempDir, tc.name)
+			os.WriteFile(filename, []byte(tc.tmplString), 0644)
+			fileRenderer := tmpl.NewFileRenderer(filesystem.DefaultFileSystem(), ".", tc.data)
+			tmpl_bytes, err := fileRenderer.RenderToBytes(filename)
+
+			if tc.wantErr {
+				require.Error(t, err)
+			} else {
+				require.NoError(t, err)
+			}
+			tmpl := string(tmpl_bytes)
+			require.Equal(t, tc.output, tmpl)
+		})
+	}
+}
+
 // TestTmplStrings tests the template string
 func TestTmplStrings(t *testing.T) {
 	c := &tmpl.Context{}
 	c.SetBasePath(".")
-	c.SetReadFile(os.ReadFile)
-	c.SetReadDir(os.ReadDir)
+	c.SetFileSystem(filesystem.DefaultFileSystem())
 	tmpl := template.New("stringTemplateTest").Funcs(c.CreateFuncMap())
 
 	tmplE2eTest.load()
